# DES01 - System Architecture

Thiết kế kiến trúc hệ thống: patterns, microservices, distributed systems.

## Best Practices

| # | Best Practice | Mô tả |
|---|---------------|-------|
| BP01 | [Architecture Patterns](DES01-BP01-Architecture-Patterns.md) | Các patterns phổ biến: Layered, Microservices, Event-driven |
| BP02 | [Architecture Decision Records](DES01-BP02-Architecture-Decision-Records.md) | Document quyết định kiến trúc |

## Tham khảo

- Martin Fowler - Patterns of Enterprise Application Architecture
- Sam Newman - Building Microservices
- Clean Architecture by Robert C. Martin
